from setuptools import setup, find_packages

setup(
    name = 'dannyisalways',
    #packages = ['tryanderror'],
    packages = find_packages(),
    version = '1.1',
    description = 'My first project',
    author = 'ekils',
    author_email = 'bobobo746@hotmail.com',
    url = 'https://github.com/ekils/dannyisalways',
    download_url = 'https://github.com/ekils/dannyisalways.git',
    keywords = ['Good Project'],
    classifiers = [],

)
